@@ -1,27 +1,35 @@
 package Data::UUID;
 
+use 5.006;
 use strict;
-
+use warnings;
 use Carp;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 require Exporter;
 require DynaLoader;
-require AutoLoader;
+use AutoLoader;
+
+our @ISA = qw(Exporter DynaLoader);
 
-@ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
+
+# This allows declaration	use Data::UUID ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory.
+our %EXPORT_TAGS = ( 'all' => [ qw(
    NameSpace_DNS
    NameSpace_OID
    NameSpace_URL
    NameSpace_X500
-);
-$VERSION = '0.147_01';
+) ] );
 
-# Preloaded methods go here.
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = qw(
+);
+our $VERSION = '0.02';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -34,28 +42,31 @@ sub AUTOLOAD {
     croak "& not defined" if $constname eq 'constant';
     my $val = constant($constname, @_ ? $_[0] : 0);
     if ($! != 0) {
-      if ($! =~ /Invalid/ || $!{EINVAL}) {
-        $AutoLoader::AUTOLOAD = $AUTOLOAD;
-        goto &AutoLoader::AUTOLOAD;
-      } else {
-        croak "Your vendor has not defined Data::UUID macro $constname";
-      }
+	if ($! =~ /Invalid/ || $!{EINVAL}) {
+	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
+	    goto &AutoLoader::AUTOLOAD;
+	}
+	else {
+	    croak "Your vendor has not defined Data::UUID macro $constname";
+	}
     }
     {
-      no strict 'refs';
-      # Fixed between 5.005_53 and 5.005_61
-      *$AUTOLOAD = sub { $val };
+	no strict 'refs';
+	# Fixed between 5.005_53 and 5.005_61
+	*$AUTOLOAD = sub { $val };
     }
     goto &$AUTOLOAD;
 }
 
 bootstrap Data::UUID $VERSION;
 
+# Preloaded methods go here.
+
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -77,28 +88,23 @@ Unique Identifiers (GUIDs/UUIDs).
 
 =head1 DESCRIPTION
 
-This module provides a framework for generating UUIDs (Universally Unique
-Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is 128
-bits long, and is guaranteed to be different from all other UUIDs/GUIDs
-generated until 3400 CE.
+   This module provides a framework for generating UUIDs (Universally Unique
+   Identifiers, also known as GUIDs (Globally Unique Identifiers). A UUID is
+   128 bits long, and is guaranteed to be different from all other UUIDs/GUIDs
+   generated until 3400 A.D. UUIDs were originally used in the Network Computing 
+   System (NCS) and later in the Open Software Foundation's (OSF) Distributed 
+   Computing Environment. Currently many different technologies rely on UUIDs to
+   provide unique identity for various software components, Microsoft COM/DCOM
+   for instance, uses GUIDs very extensively to uniquely identify classes, 
+   applications and components across network-connected systems.
+   The algorithm for UUID generation, used by this extension, is described in the
+   Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz. It provides
+   reasonably efficient and reliable framework for generating UUIDs and supports
+   fairly high allocation rates - 10 million per second per machine, and therefore,
+   is suitable for identifying both - extremely short-lived and very persistent 
+   objects on a given system as well as across the network.
+   This modules provides several methods to create a UUID:
 
-UUIDs were originally used in the Network Computing System (NCS) and later in
-the Open Software Foundation's (OSF) Distributed Computing Environment.
-Currently many different technologies rely on UUIDs to provide unique identity
-for various software components. Microsoft COM/DCOM for instance, uses GUIDs
-very extensively to uniquely identify classes, applications and components
-across network-connected systems.
-
-The algorithm for UUID generation, used by this extension, is described in the
-Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz
-(L<http://hegel.ittc.ku.edu/topics/internet/internet-drafts/draft-l/draft-leach-uuids-guids-01.txt>).
-It provides reasonably efficient and reliable framework for generating UUIDs
-and supports fairly high allocation rates -- 10 million per second per machine
--- and therefore is suitable for identifying both extremely short-lived and
-very persistent objects on a given system as well as across the network.
-
-This modules provides several methods to create a UUID:
- 
    # creates binary (16 byte long binary value) UUID.
    $ug->create();
    $ug->create_bin();
@@ -106,21 +112,21 @@ This modules provides several methods to create a UUID:
    # creates binary (16-byte long binary value) UUID based on particular
    # namespace and name string.
    $ug->create_from_name(<namespace>, <name>);
-   $ug->create_from_name_bin(<namespace>, <name>);
+   $ug->create_from_name_bin(<namespace>, <name>); 
 
    # creates UUID string, using conventional UUID string format,
-   # such as: 4162F712-1DD2-11B2-B17E-C09EFE1DC403
+   # such as: 4162F712-1DD2-11B2-B17E-C09EFE1DC403 
    $ug->create_str();
    $ug->create_from_name_str(<namespace>, <name>);
 
    # creates UUID string as a hex string,
-   # such as: 0x4162F7121DD211B2B17EC09EFE1DC403
+   # such as: 0x4162F7121DD211B2B17EC09EFE1DC403 
    $ug->create_hex();
    $ug->create_from_name_hex(<namespace>, <name>);
 
    # creates UUID string as a Base64-encoded string
    $ug->create_b64();
-   $ug->create_from_name_b64(<namespace>, <name>);
+   $ug->create_from_name_b64(<namespace>, <name>);   
 
    Binary UUIDs can be converted to printable strings using following methods:
 
@@ -137,7 +143,7 @@ This modules provides several methods to create a UUID:
 
    # recreate binary UUID from string
    $ug->from_string(<uuid>);
-   $ug->from_hexstring(<uuid>);
+   $ug->from_hexstring(<uuid>);	
 
    # recreate binary UUID from Base64-encoded string
    $ug->from_b64string(<uuid>);
@@ -148,7 +154,7 @@ This modules provides several methods to create a UUID:
    # than, equals to, or greater than uuid2
    $ug->compare(<uuid1>, <uuid2>);
 
-Examples:
+   Examples:
 
    use Data::UUID qw(:all);
 
@@ -160,30 +166,18 @@ Examples:
 
 =head2 EXPORT
 
-The module allows exporting of several standard namespace UUIDs:
+   The module allows exporting of several standard namespace UUIDs:
+      NameSpace_DNS
+      NameSpace_URL
+      NameSpace_OID
+      NameSpace_X500
 
-=over
-
-=item NameSpace_DNS
-
-=item NameSpace_URL
-
-=item NameSpace_OID
-
-=item NameSpace_X500
-
-=back
- 
 =head1 AUTHOR
 
-Alexander Golomshtok<agolomsh@cpan.org>
+Alexander Golomshtok<lt>golomshtok_alexander@jpmorgan.com<gt>
 
 =head1 SEE ALSO
 
-The Internet Draft "UUIDs and GUIDs" by Paul J. Leach and Rich Salz:
-L<http://www.globecom.net/ietf/draft/draft-leach-uuids-guids-01.html>
-"Primary Key Reengineering Projects: The Problem" by Tom Johnston
-L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=1866>
-"Primary Key Reengineering Projects: The Solution" by Tom Johnston
-L<http://www.dmreview.com/editorial/dmreview/print_action.cfm?EdID=2004>
+L<perl>.
+
 =cut
